<!DOCTYPE TS><TS>
    <context>
        <name>@default</name>
        <message>
            <source>CFDSTUDY_INVALID_ENV</source>
            <translation>CFD code environment not found!</translation>
        </message>
        <message>
            <source>CFDSTUDY_INVALID_SOLVER_NAME</source>
            <translation>%1 is an invalid name of solver ! It must be %2 or %3 !</translation>
        </message>
        <message>
            <source>CFDSTUDY_MENU</source>
            <translation>CFDSTUDY</translation>
        </message>
        <message>
            <source>CFDSTUDY_TOOL_BAR</source>
            <translation>CFDSTUDY</translation>
        </message>
        <message>
            <source>NEW_CFDSTUDY_STUDY_TEXT</source>
            <translation>New CFD study</translation>
        </message>
        <message>
            <source>NEW_CFDSTUDY_STUDY_TIP</source>
            <translation>Creating new CFD study</translation>
        </message>
        <message>
            <source>NEW_CFDSTUDY_STUDY_SB</source>
            <translation>Creating new CFD study</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_STUDY_TEXT</source>
            <translation>Set CFD study Location</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_STUDY_TIP</source>
            <translation>Set location for new CFD study</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_STUDY_SB</source>
            <translation>Set location for new CFD study</translation>
        </message>
        <message>
            <source>SET_STUDY_LOCATION_BROWSE_CAPTION</source>
            <translation>Choose CFD study location</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_ENVIRONMENT_PROFILE</source>
            <translation>Choose the environment profile file</translation>
        </message>
        <message>
            <source>ADD_CFDSTUDY_CASE_TEXT</source>
            <translation>Add Case</translation>
        </message>
        <message>
            <source>ADD_CFDSTUDY_CASE_TIP</source>
            <translation>Adding Case</translation>
        </message>
        <message>
            <source>ADD_CFDSTUDY_CASE_SB</source>
            <translation>Adding Case</translation>
        </message>
        <message>
            <source>EDIT_CFDSTUDY_CASE_TEXT</source>
            <translation>Case Configuration</translation>
        </message>
        <message>
            <source>EDIT_CFDSTUDY_CASE_TIP</source>
            <translation>Case configuration</translation>
        </message>
        <message>
            <source>EDIT_CFDSTUDY_CASE_SB</source>
            <translation>Case configuration</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_CASE_TEXT</source>
            <translation>Run Case</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_CASE_TIP</source>
            <translation>Run Case</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_CASE_SB</source>
            <translation>Run Case</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_GUI_TEXT</source>
            <translation>Launch GUI</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_GUI_TIP</source>
            <translation>Launching of CFD code interface</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_GUI_SB</source>
            <translation>Launching of CFD code interface</translation>
        </message>
        <message>
            <source>LAUNCH_GUI_WITH_OPTION_TEXT</source>
            <translation>Launch GUI with options</translation>
        </message>
        <message>
            <source>LAUNCH_ICS_WITH_OPTION_TIP</source>
            <translation>Launching of CFD code interface with options</translation>
        </message>
        <message>
            <source>LAUNCH_GUI_WITH_OPTION_SB</source>
            <translation>Launching of CFD code interface with options</translation>
        </message>
        <message>
            <source>UPDATE_CFDSTUDY_OBJBROWSER_TEXT</source>
            <translation>Update Object Browser</translation>
        </message>
        <message>
            <source>UPDATE_CFDSTUDY_OBJBROWSER_TIP</source>
            <translation>Updating Object Browser (reread root directory)</translation>
        </message>
        <message>
            <source>UPDATE_CFDSTUDY_OBJBROWSER_SB</source>
            <translation>Updating Object Browser (reread root directory)</translation>
        </message>
        <message>
            <source>INFO_CFDSTUDY_TEXT</source>
            <translation>CFDSTUDY Information</translation>
        </message>
        <message>
            <source>INFO_CFDSTUDY_TIP</source>
            <translation>Showing main CFDSTUDY Information</translation>
        </message>
        <message>
            <source>INFO_CFDSTUDY_SB</source>
            <translation>Showing main CFDSTUDY Information</translation>
        </message>
        <message>
            <source>RUN_SCRIPT_ACTION_TEXT</source>
            <translation>Run script...</translation>
        </message>
        <message>
            <source>RUN_SCRIPT_ACTION_TIP</source>
            <translation>Run script...</translation>
        </message>
        <message>
            <source>RUN_SCRIPT_ACTION_SB</source>
            <translation>Run script...</translation>
        </message>
        <message>
            <source>RUN_SCRIPT_ACTION_ACCESS_ERROR</source>
            <translation>You have not access rights for this script execution!</translation>
        </message>
        <message>
            <source>SOLVER_FILE_MENU_TEXT</source>
            <translation>CFD_Code</translation>
        </message>
        <message>
            <source>SOLVER_SAVE_ACTION_TEXT</source>
            <translation>Save CFD Data File</translation>
        </message>
        <message>
            <source>SOLVER_SAVE_ACTION_TIP</source>
            <translation>Save CFD Data File</translation>
        </message>
        <message>
            <source>SOLVER_SAVE_ACTION_SB</source>
            <translation>Save CFD Data File</translation>
        </message>
        <message>
            <source>SOLVER_SAVEAS_ACTION_TEXT</source>
            <translation>Save as CFD Data File</translation>
        </message>
        <message>
            <source>SOLVER_SAVEAS_ACTION_TIP</source>
            <translation>Save as CFD Data File</translation>
        </message>
        <message>
            <source>SOLVER_SAVEAS_ACTION_SB</source>
            <translation>Save as CFD Data File</translation>
        </message>
        <message>
            <source>XML_DATA_FILE</source>
            <translation>Error into the XML Data File %1</translation>
        </message>
        <message>
            <source>XML_DATA_FILE_ERROR</source>
            <translation>Data File error for %1</translation>
        </message>
        <message>
            <source>SOLVER_TOOLS_MENU_TEXT</source>
            <translation>Tools</translation>
        </message>
        <message>
            <source>SOLVER_OPENSHELL_ACTION_TEXT</source>
            <translation>Open Shell</translation>
        </message>
        <message>
            <source>SOLVER_OPENSHELL_ACTION_TIP</source>
            <translation>Open Shell</translation>
        </message>
        <message>
            <source>SOLVER_OPENSHELL_ACTION_SB</source>
            <translation>Open Shell</translation>
        </message>
        <message>
            <source>SOLVER_DISPLAYCASE_ACTION_TEXT</source>
            <translation>Case display</translation>
        </message>
        <message>
            <source>SOLVER_DISPLAYCASE_ACTION_TIP</source>
            <translation>Case display</translation>
        </message>
        <message>
            <source>SOLVER_DISPLAYCASE_ACTION_SB</source>
            <translation>Case display</translation>
        </message>
        <message>
            <source>SOLVER_HELP_MENU_TEXT</source>
            <translation>CFD_Code</translation>
        </message>
        <message>
            <source>SOLVER_HELPABOUT_ACTION_TEXT</source>
            <translation>About</translation>
        </message>
        <message>
            <source>SOLVER_HELPABOUT_ACTION_TIP</source>
            <translation>About</translation>
        </message>
        <message>
            <source>SOLVER_HELPABOUT_ACTION_SB</source>
            <translation>About</translation>
        </message>    
        <message>
            <source>SATURNE_FILE_MENU_TEXT</source>
            <translation>Code_Saturne</translation>
        </message>
        <message>
            <source>SATURNE_SAVE_ACTION_TEXT</source>
            <translation>Save SaturneGUI data xml file</translation>
        </message>
        <message>
            <source>SATURNE_SAVE_ACTION_TIP</source>
            <translation>Save SaturneGUI data xml file</translation>
        </message>
        <message>
            <source>SATURNE_SAVE_ACTION_SB</source>
            <translation>Save SaturneGUI data xml file</translation>
        </message>
        <message>
            <source>SATURNE_SAVEAS_ACTION_TEXT</source>
            <translation>Save as SaturneGUI data xml file</translation>
        </message>    
        <message>
            <source>SATURNE_SAVEAS_ACTION_TIP</source>
            <translation>Save as SaturneGUI data xml file</translation>
        </message>
        <message>
            <source>SATURNE_SAVEAS_ACTION_SB</source>
            <translation>Save as SaturneGUI data xml file</translation>
        </message>
        <message>
            <source>SATURNE_TOOLS_MENU_TEXT</source>
            <translation>Tools</translation>
        </message>
        <message>
            <source>SATURNE_OPENSHELL_ACTION_TEXT</source>
            <translation>Open Shell</translation>
        </message>
        <message>
            <source>SATURNE_OPENSHELL_ACTION_TIP</source>
            <translation>Open Shell</translation>
        </message>
        <message>
            <source>SATURNE_OPENSHELL_ACTION_SB</source>
            <translation>Open Shell</translation>
        </message>
        <message>
            <source>SATURNE_DISPLAYCASE_ACTION_TEXT</source>
            <translation>Display current Case</translation>
        </message>
        <message>
            <source>SATURNE_DISPLAYCASE_ACTION_TIP</source>
            <translation>Display current Case</translation>
        </message>
        <message>
            <source>SATURNE_DISPLAYCASE_ACTION_SB</source>
            <translation>Display current Case</translation>
        </message>
        <message>
            <source>DELETE_ACTION_TEXT</source>
            <translation>Delete</translation>
        </message>
        <message>
            <source>DELETE_ACTION_TIP</source>
            <translation>Delete</translation>
        </message>
        <message>
            <source>DELETE_ACTION_SB</source>
            <translation>Delete</translation>
        </message>
        <message>
            <source>REMOVE_ACTION_TEXT</source>
            <translation>Remove</translation>
        </message>
        <message>
            <source>REMOVE_ACTION_TIP</source>
            <translation>Remove</translation>
        </message>
        <message>
            <source>REMOVE_ACTION_SB</source>
            <translation>Remove</translation>
        </message>
        <message>
            <source>REMOVE_ACTION_CONFIRM_MESS</source>
            <translation>Do You want to remove of %1 from this study?</translation>
        </message>
        <message>
            <source>CLOSE_CFD_GUI_ACTION_TEXT</source>
            <translation>Close CFD GUI</translation>
        </message>
        <message>
            <source>CLOSE_CFD_GUI_ACTION_TIP</source>
            <translation>Close CFD GUI</translation>
        </message>
        <message>
            <source>CLOSE_CFD_GUI_ACTION_SB</source>
            <translation>Close CFD GUI</translation>
        </message>
        <message>
            <source>VIEW_ACTION_TEXT</source>
            <translation>View</translation>
        </message>
        <message>
            <source>VIEW_ACTION_TIP</source>
            <translation>View</translation>
        </message>
        <message>
            <source>VIEW_ACTION_SB</source>
            <translation>View</translation>
        </message>
        <message>
            <source>EDIT_ACTION_TEXT</source>
            <translation>Edit</translation>
        </message>
        <message>
            <source>EDIT_ACTION_TIP</source>
            <translation>Edit</translation>
        </message>
        <message>
            <source>EDIT_ACTION_SB</source>
            <translation>Edit</translation>
        </message>
        <message>
            <source>MOVE_TO_DRAFT_ACTION_TEXT</source>
            <translation>Move to DRAFT</translation>
        </message>
        <message>
            <source>MOVE_TO_DRAFT_ACTION_TIP</source>
            <translation>Move to DRAFT</translation>
        </message>
        <message>
            <source>MOVE_TO_DRAFT_ACTION_SB</source>
            <translation>Move to DRAFT</translation>
        </message>
        <message>
            <source>OVERWRITE_CONFIRM_MESS</source>
            <translation>Target file already exists. Do You want to overwrite it?</translation>
        </message>
        <message>
            <source>COPY_IN_DATA_ACTION_TEXT</source>
            <translation>Copy in DATA</translation>
        </message>
        <message>
            <source>COPY_IN_DATA_ACTION_TIP</source>
            <translation>Copy in DATA</translation>
        </message>
        <message>
            <source>COPY_IN_DATA_ACTION_SB</source>
            <translation>Copy in DATA</translation>
        </message>
        <message>
            <source>COPY_IN_SRC_ACTION_TEXT</source>
            <translation>Copy in SRC</translation>
        </message>
        <message>
            <source>COPY_IN_SRC_ACTION_TIP</source>
            <translation>Copy in SRC</translation>
        </message>
        <message>
            <source>COPY_IN_SRC_ACTION_SB</source>
            <translation>Copy in SRC</translation>
        </message>
        <message>
            <source>COPY_CASE_FILE_ACTION_TEXT</source>
            <translation>Copy into another Case</translation>
        </message>
        <message>
            <source>COPY_CASE_FILE_ACTION_TIP</source>
            <translation>Copy into an other Case</translation>
        </message>
        <message>
            <source>COPY_CASE_FILE_ACTION_SB</source>
            <translation>Copy into an other Case</translation>
        </message>
        <message>
            <source>EXPORT_IN_PARAVIS_ACTION_TEXT</source>
            <translation>Export In ParaViS</translation>
        </message>
        <message>
            <source>EXPORT_IN_PARAVIS_ACTION_TIP</source>
            <translation>Export In ParaViS</translation>
        </message>
        <message>
            <source>EXPORT_IN_PARAVIS_ACTION_SB</source>
            <translation>Export In ParaViS</translation>
        </message>
        <message>
            <source>EXPORT_IN_SMESH_ACTION_TEXT</source>
            <translation>Export in SMESH</translation>
        </message>
        <message>
            <source>EXPORT_IN_SMESH_ACTION_TIP</source>
            <translation>Export in SMESH</translation>
        </message>
        <message>
            <source>EXPORT_IN_SMESH_ACTION_SB</source>
            <translation>Export in SMESH</translation>
        </message>
        <message>
            <source>EXPORT_IN_SMESH_ACTION_WARNING</source>
            <translation>Some errors occored during EXPORT operation!</translation>
        </message>
        <message>
            <source>CONVERT_IN_MED_ACTION_TEXT</source>
            <translation>Convert to MED</translation>
        </message>
        <message>
            <source>CONVERT_IN_MED_ACTION_TIP</source>
            <translation>Convert to MED</translation>
        </message>
        <message>
            <source>CONVERT_IN_MED_ACTION_SB</source>
            <translation>Convert to MED</translation>
        </message>
        <message>
            <source>ECS_CONVERT_ACTION_TEXT</source>
            <translation>Convert to MED</translation>
        </message>
        <message>
            <source>ECS_CONVERT_ACTION_TIP</source>
            <translation>Convert to MED</translation>
        </message>
        <message>
            <source>ECS_CONVERT_ACTION_SB</source>
            <translation>Convert to MED</translation>
        </message>
        <message>
            <source>CHECK_COMPILATION_ACTION_TEXT</source>
            <translation>Check compilation</translation>
        </message>
        <message>
            <source>CHECK_COMPILATION_ACTION_TIP</source>
            <translation>Check compilation</translation>
        </message>
        <message>
            <source>CHECK_COMPILATION_ACTION_SB</source>
            <translation>Check compilation</translation>
        </message>
        <message>
            <source>PROCESS_DLG_PROCESS_NOT_SUCCESS</source>
            <translation>Some errors occured during Solver execution. See lof files for details</translation>
        </message>
        <message>
            <source>PROCESS_DLG_PROCESS_SUCCESS</source>
            <translation>Solver execution complete. See lof files for details</translation>
        </message>
        <message>
            <source>PROCESS_DLG_PROCESS_STOP</source>
            <translation>Solver execution stoped by user</translation>
        </message>
        <message>
            <source>PROCESS_DLG_PROCESS_ERROR</source>
            <translation>Solver execution complete with some errors. See lof files for details</translation>
        </message>
        <message>
            <source>PROCESS_DLG_CAPTION</source>
            <translation>Calculation process manager</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_TAB</source>
            <translation>CFDSTUDY</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_GEN_GROUP</source>
            <translation>General</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_KERNEL</source>
            <translation>Home Kernel CFDSTUDY</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_EDITOR</source>
            <translation>xemacs</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_READER</source>
            <translation>xemacs</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_DIFF</source>
            <translation>Diff tool</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_DISPLAY</source>
            <translation>Display</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_ENV_GROUP</source>
            <translation>Environment</translation>
        </message>
        <message>
            <source>CFDSTUDY_PREF_SHOW_INFO_DLG</source>
            <translation>Don't show Information Dialog on first module activation</translation>
        </message>

        <message>
            <source>CFDSTUDY_ENV_WARN_MESSAGE</source>
            <translation>You can't activate CFDSTUDY module without required enviroment variables. Please, set it</translation>
        </message>
        <message>
            <source>STMSG_SET_STUDY_LOCATION</source>
            <translation>Setting study location...</translation>
        </message>
        <message>
            <source>STMSG_UPDATE_STUDY</source>
            <translation>Updating study structure...</translation>
        </message>
        <message>
            <source>STMSG_ADD_CASE</source>
            <translation>Adding CFD cases...</translation>
        </message>
        <message>
            <source>STMSG_ECS_CONVERT</source>
            <translation>Convertion to MED format</translation>
        </message>
        <message>
            <source>STMSG_RUN_SCRIPT</source>
            <translation>Running Code_Saturne</translation>
        </message>
        <message>
            <source>STMSG_CHECK_COMPILATION</source>
            <translation>Check compilation</translation>
        </message>
        <message>
            <source>ENV_DLG_INVALID_DIRECTORY</source>
            <translation>Directory %1 does not exists!!! </translation>
        </message>
        <message>
            <source>ENV_DLG_INVALID_FILE</source>
            <translation>%1 : File %2  does not exists!!! </translation>
        </message>
        <message>
            <source>INFO_DLG_INVALID_ENV</source>
            <translation>Invalid environment for %1 ! </translation>
        </message>
        <message>
            <source>STMSG_UPDATE_STUDY_INCOMING</source>
            <translation> ...Study structure updating NOW ! </translation>
        </message>
        <message>
            <source>INFO_DLG_CASE</source>
            <translation> Study Case %1 already exists ! </translation>
        </message>

    </context>
    <context>
        <name>InfoDialogHandler</name>
        <message>
            <source>INFO_DLG_CAPTION</source>
            <translation>CFDSTUDY information</translation>
        </message>
        <message>
            <source>INFO_DLG_NOT_INSTALLED</source>
            <translation>Not Installed!!!</translation>
        </message>
        <message>
            <source>INFO_DLG_ENV_GROUP</source>
            <translation>Environment Variables</translation>
        </message>
        <message>
            <source>INFO_DLG_ENV_REQUIRED</source>
            <translation>%1 (required)</translation>
        </message>
        <message>
            <source>INFO_DLG_ENV_OPTIONAL</source>
            <translation>%1(optional)</translation>
        </message>
        <message>
            <source>INFO_DLG_CHECKBOX_TEXT</source>
            <translation>Don't show me again on startup module</translation>
        </message>
        <message>
            <source>INFO_DLG_ENV_EDIT</source>
            <translation>Edit environnement...</translation>
        </message>
        <message>
            <source>INFO_DLG_CFDCODE_TITLE</source>
            <translation>Select CFD code</translation>
        </message>
        <message>
            <source>INFO_DLG_SATURNE_TEXT</source>
            <translation>Code_Saturne</translation>
        </message>
        <message>
            <source>INFO_DLG_NEPTUNE_TEXT</source>
            <translation>NEPTUNE_CFD</translation>
        </message>
        <message>
            <source>INFO_DLG_INVALID_ENV</source>
            <translation>Invalid environment! Please, correct required or non-existent variables:</translation>
        </message>
        <message>
            <source>DLG_OK_BUTTON_TEXT</source>
            <translation>OK</translation>
        </message>
    </context>
    <context>
        <name>EnvSettingsDialogHandler</name>
        <message>
            <source>ENV_DLG_HEADER_VARIABLE</source>
            <translation>Variable</translation>
        </message>
        <message>
            <source>ENV_DLG_HEADER_MEANING</source>
            <translation>Meaning</translation>
        </message>
        <message>
            <source>ENV_DLG_BTN_TOOLTIP</source>
            <translation>Click for browsing environment variable from Salome Browser</translation>
        </message>
        <message>
            <source>ENV_DLG_LOAD_BTN_TEXT</source>
            <translation>Load from file</translation>
        </message>
        <message>
            <source>DLG_OK_BUTTON_TEXT</source>
            <translation>OK</translation>
        </message>
        <message>
            <source>DLG_ABORT_BUTTON_TEXT</source>
            <translation>Abort</translation>
        </message>
        <message>
            <source>ENV_DLG_CAPTION</source>
            <translation>CFDSTUDY environment</translation>
        </message>
        <message>
            <source>ENV_DLG_INVALID_ENV</source>
            <translation>Directory of %1 variable does not exists!!!</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_ENVIRONMENT_PROFILE</source>
            <translation>Choose the environment profile file</translation>
        </message>
        <message>
            <source>SET_STUDY_LOCATION_BROWSE_CAPTION</source>
            <translation>Choose CFDSTUDY Study location</translation>
        </message>
    </context>
    <context>
        <name>SetTreeLocationDialogHandler</name>
        <message>
            <source>DLG_OK_BUTTON_TEXT</source>
            <translation>OK</translation>
        </message>
        <message>
            <source>DLG_CANCEL_BUTTON_TEXT</source>
            <translation>CANCEL</translation>
        </message>
        <message>
            <source>LOCATION_DLG_CAPTION</source>
            <translation>Location of CFDSTUDY study</translation>
        </message>
        <message>
            <source>LOCATION_DLG_STUDY_NAME</source>
            <translation>Study name</translation>
        </message>
        <message>
            <source>LOCATION_DLG_CASE_NAME</source>
            <translation>Cases</translation>
        </message>
        <message>
            <source>LOCATION_DLG_ADD_CASE</source>
            <translation>Add new Cases</translation>
        </message>
        <message>
            <source>LOCATION_DLG_STUDY_DIR_LABEL</source>
            <translation>Study location</translation>
        </message>
        <message>
            <source>SET_STUDY_LOCATION_BROWSE_CAPTION</source>
            <translation>Choose CFDSTUDY Study location</translation>
        </message>
        <message>
            <source>LOCATION_DLG_ERROR_OPEN_MESS</source>
            <translation>The Directory %1 is already opened! Please, choose another directory.</translation>
        </message>
        <message>
            <source>LOCATION_DLG_WARN_MESS</source>
            <translation>The Directory %1 already exists. Do You want to use that study?</translation>
        </message>
        <message>
            <source>LOCATION_DLG_WARN_MESS1</source>
            <translation>The Directory %1 already exists. Do You want to create a new study?</translation>
        </message>
        <message>
            <source>LOCATION_DLG_ERROR_MESS</source>
            <translation>The Directory %1 does not exist or Study Name is empty! Please, choose another directory.</translation>
        </message>
    </context>
    <context>
        <name>RunCaseDialogHandler</name>
        <message>
            <source>RUNCASE_DLG_RUN_BUTTON_TEXT</source>
            <translation>Run Case</translation>
        </message>
        <message>
            <source>DLG_CANCEL_BUTTON_TEXT</source>
            <translation>Cancel</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_MODE_TITLE</source>
            <translation>Mode</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_RUN_MODE_BTN_TEXT</source>
            <translation>Run</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_MAIN_GROUP_TITLE</source>
            <translation>Location of run script</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_STUDY_LABEL_TEXT</source>
            <translation>Study</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_CASE_LABEL_TEXT</source>
            <translation>Case</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_CAPTION</source>
            <translation>Run Case</translation>
        </message>
        <message>
            <source>RUNCASE_DLG_COMPILE_MODE_BTN_TEXT</source>
            <translation>Compile only</translation>
        </message>
    </context>
    <context>
        <name>ECSConversionDialogHandler</name>
        <message>
            <source>ECSCONVERT_DLG_CONVERT_BUTTON</source>
            <translation>Convert</translation>
        </message>
        <message>
            <source>DLG_CANCEL_BUTTON_TEXT</source>
            <translation>Cancel</translation>
        </message>
        <message>
            <source>ECSCONVERT_DLG_OPTIONS_TITLE</source>
            <translation>Options</translation>
        </message>
        <message>
            <source>ECSCONVERT_DLG_RESULT_LABEL_TEXT</source>
            <translation>Result med file</translation>
        </message>
        <message>
            <source>ECSCONVERT_DLG_CAPTION</source>
            <translation>Conversion to MED</translation>
        </message>
    </context>
    <context>
        <name>CopyDialogHandler</name>
        <message>
            <source>COPY_DLG_COPY_BUTTON</source>
            <translation>Copy</translation>
        </message>
        <message>
            <source>DLG_CANCEL_BUTTON_TEXT</source>
            <translation>Cancel</translation>
        </message>
        <message>
            <source>COPY_DLG_DEST_FILE_LABEL</source>
            <translation>File</translation>
        </message>
        <message>
            <source>COPY_DLG_DEST_CASE_LABEL</source>
            <translation>Case</translation>
        </message>
        <message>
            <source>COPY_DLG_DEST_STUDY_LABEL</source>
            <translation>Study</translation>
        </message>
        <message>
            <source>COPY_DLG_SOURCE_CASE_LABEL</source>
            <translation>Case</translation>
        </message>
        <message>
            <source>COPY_DLG_FILE_NAME_LABEL</source>
            <translation>File</translation>
        </message>
        <message>
            <source>COPY_DLG_CAPTION</source>
            <translation>Copy file of parameters</translation>
        </message>
        <message>
            <source>COPY_DLG_EXISTS_ERROR_CAPTION</source>
            <translation>Error</translation>
        </message>
        <message>
            <source>COPY_DLG_EXISTS_ERROR_TEXT</source>
            <translation>Destinate file already exists!</translation>
        </message>
    </context>
    <context>
        <name>GUIActivationDialogHandler</name>
        <message>
            <source>GUIACTIVATE_DLG_ACTIVATE_BTN</source>
            <translation>Activate</translation>
        </message>
        <message>
            <source>DLG_CANCEL_BUTTON_TEXT</source>
            <translation>Cancel</translation>
        </message>
        <message>
            <source>GUIACTIVATE_DLG_OPTIONS_TITLE</source>
            <translation>Options</translation>
        </message>
        <message>
            <source>GUIACTIVATE_DLG_NEW_CASE</source>
            <translation>New Case</translation>
        </message>
        <message>
            <source>ICSACTIVATE_DLG_CAPTION</source>
            <translation>Code_Saturne GUI activation</translation>
        </message>
        <message>
            <source>ICSACTIVATE_DLG_CASE_LABEL</source>
            <translation>Case selection:</translation>
        </message>
        <message>
            <source>IPBACTIVATE_DLG_CAPTION</source>
            <translation>NEPTUNE_CFD GUI activation</translation>
        </message>
        <message>
            <source>IPBACTIVATE_DLG_CASE_LABEL</source>
            <translation>Case for NEPTUNE_CFD GUI activation</translation>
        </message>
        <message>
            <source>ICSACTIVATE_DLG_BAD_CASE_MESS</source>
            <translation>File SaturneGUI is absent. You can't activate the GUI on this Case!</translation>
        </message>
        <message>
            <source>IPBACTIVATE_DLG_BAD_CASE_MESS</source>
            <translation>File NeptuneGUI is absent. You can't activate the GUI on this Case!</translation>
        </message>
    </context>
</TS>
